function [ kend ] = Kendl1( data1, data2 )
% KENDL1 computes Kendall's tau for rank correlation
% PT, 14 Oct 2015 - from Pascal code in Press et al., 1989, p. 541
% unlike Pascal, Matlab does not need initial declaration of variables
% have slightly changed names in some cases (e.g. 'is' to 'iss')
% INPUT
%    data1, data2 = y1 and y2 variables, column or row vectors
%                   (can be either (and different) as long as 1D)
% OUTPUT
%   kend = structure in which the fields are
%       .tau = correlation coefficient
%       .prob = probability on hypothesis of random association
%               (2-tailed test)

% first, a check - not in Press et al.
if length(data1) ~= length(data2),
    fprintf('*** ERROR IN LENGTH OF DATA VECTORS SUPPLIED TO KENDL1\n');
    kend.tau = NaN;kend.prob = NaN;
else % do the Press et al algorithm
    n1 = 0;
    n2= 0;
    iss = 0;
    n = length(data1); % assuming that data1 and data2 are same length
    for j = 1:n,
        for k = j+1:n,
            a1 = data1(j) - data1(k);
            a2 = data2(j) - data2(k);
            aa = a1*a2;
            if aa ~= 0,
                n1 = n1 + 1;
                n2 = n2 + 1;
                if aa > 0,
                    iss = iss + 1;
                else
                    iss = iss - 1;
                end
            else
                if a1 ~= 0, n1 = n1 + 1; end
                if a2 ~= 0, n2 = n2 + 1; end
            end
        end % k loop
    end % j loop
    %
    kend.tau = iss/(sqrt(n1)*sqrt(n2));
    svar = (4 * n + 10)/(9 * n * (n-1));
    z = kend.tau/sqrt(svar); % standrad deviations (from zero) of tau
    kend.prob = erfc(abs(z)/1.4142136); 
    % using Matlab 'complementary error function' ERFC for 
    %   Press et al. ERFCC  - see p. 184-5 in Press et al. 
    %
end
end

