function [] = tsplot2(data1, cd, data2)
% TSPLOT2 makes plots of timeseries data with ratio
%
% input
%   data1: 2D array of data in which
%       columns are: year.dec, y1, y2 [, more y]
%   cd : structure, control data
%   data2 : optional 2nd array of data
%           

% made by PT, 8 - 9 August 2008 as TSPLOT (called by PCI)
% PT, 6 Oct 2013 - plots nothing (rather than line) in years empty of data
% PT, 1 Mar 2015 - new version TSPLOT2, also plots ratio y1/(y1+y2)
% PT. 4 Sep 2015 - outputs using PIPRINT
% PT, 7 Sep 2015 - tidying up z1 and z2 values; only one input file
% PT, 30 Sep 2015 - allows for optional 2 data files
% PT, 12 Nov 2015 - lists data N in each year prior to year selection
% =================================================================
%
global prog_name uname
fname = mfilename;
%% 1. START-UP
fprintf('%s\n', 'Graphing time-series of abundances with tsplot2:');
data=data1; 
coldat = cd.c1dat; % column for date
colsv1 = cd.c1sv1; % columns for y variables
colsv2 = cd.c1sv2;
ddes = cd.d1des; % data source/description
colsvt1 = cd.c1svt1;  % numbers or biomass [only col 1 significant]
if colsvt1 == 1, % numbers
    z1 = cd.z1; % y value for zero
    z2 = cd.z2;
else
    z1 = cd.bz1;
    z2 = cd.bz2;
end
dsv1 = cd.dsv1; % names for variables and units
dsv2 = cd.dsv2;
if cd.ndf > 1.5, % there are two data-files, so check and update
  fprintf('%s\n', 'Two data files have been loaded:');  
  fprintf('%s\n', ['1. ' cd.df1n] );  
  fprintf('%s\n', ['2. ' cd.df2n] );
  wf = input('Which one do you want [1]:');
  if isempty(wf) || wf < 1.5, wf = 1; else wf = 2; end
  if wf > 1.5, 
    data=data2; 
    coldat = cd.c2dat; % column for date
    colsv1 = cd.c2sv1; % columns for y variables
    colsv2 = cd.c2sv2;
    ddes = cd.d2des; % data source/description
  end
end
%
years=unique(floor(data(:,coldat)));
fprintf('%s\n', 'Available years of data are:');
% new 12 Nov
nr = zeros(1, length(years));
for yr = 1:length(years),
    nr(yr) = sum(ismember(floor(data(:,coldat)),years(yr)));
    %nr(yr) = length(floor(data(:,coldat)) == years(yr));
    fprintf('%8.0f (N = %8.0f) \n', years(yr), nr(yr));
end
% fprintf('%8.0f \n', years');
minyear=min(years); maxyear=max(years);
begin_year=floor(getnum(...
    'Enter (integer) start year for plot :', minyear));
% add 0.999 to integer end_year include whole year
end_year=0.999 + floor(getnum(... 
    'Enter (integer) last full year for plot :', maxyear));
% 
% call extract2 with raw data; it returns transformed Y1 and Y2
% only uses one minimum, so
z = min([z1 z2]);
localdata = ...
     extract2(begin_year, end_year, z1, z2,...
        data, coldat, colsv1, colsv2, cd.mf);
    % deal with large gaps (> 1 yr) by inserting a row of NaN [6 Oct 13]
    % do this for any year between begin_year and end_year not in years 
    empty_years = setdiff(begin_year:end_year, years);
    ley = length(empty_years);
    lld = length(localdata(:,1));
    nogood = ones(ley,1)*NaN; % column vector of NaN
    localdata(lld+1:lld+ley,1) = empty_years';
    localdata(lld+1:lld+ley,2) = nogood;
    localdata(lld+1:lld+ley,3) = nogood;
    % now resort localdata (by rows) on column 1
    localdata = sortrows(localdata,1);
    % resume earlier commands
year = localdata(:,1);
y1 = localdata(:,2);
y2 = localdata(:,3);
% column 4, month, not used
% NEW 1 MARCH IN TSPLOT2 - CALCULATE RATIO
nly1 = 10.^y1 - z;% de-transform
nly2 = 10.^y2 - z;
ry3 = nly1./(nly1+nly2);
% %%%%%%%%

clf;
% prepare scales [currently assuming that colsvt1 and colsvt2 the same]
%  - updated 6 Oct 2013
%     if cd.c1svt1 == 1, % using cell numbers as variable
%         minX=2.0;maxX=8.0;% default - changed from 6 to 8 on 16 Aug 2011
%     else % using biomass as the variable
%          minX=-5.0;maxX=2.0; % added 29 April 2013
%     end
%     % adjust maxima and minima if necessary
%      maxSV = max([max(y1) max(y2)] );
%      if maxSV>maxX, maxX=ceil(maxSV); end
%      maxY=maxX;
%      minSV = min([min(y1) min(y2) log10(z)]);
%      if minSV < minX, minX=floor(minSV); end
%     minY=minX;
% - revised 9 Oct 2015
if cd.c1svt1 == 1, % using cell numbers
    minX = cd.nmin; maxX = cd.nmax; % not used
    minY = cd.nmin; maxY = cd.nmax;
else
    minX = cd.bmin; maxX = cd.bmax; % not used
    minY = cd.bmin; maxY = cd.bmax;
end
%
if cd.mf > 0,
    mess = ' (monthly means)';
else
    if cd.mf < 0,
        mess = [' (subsampled 1 in ' num2str(-cd.mf) ')'];
    else
        mess = ' (all data used)';
    end
end
% make axis run to next whole year
xlimits = [begin_year ceil(end_year)]; 
lmin = [log10(z) log10(z)]; % for minimum
xmpos = xlimits(1) + 0.02*(xlimits(2)-xlimits(1));
ympos = lmin(1) - 0.05*(maxY - minY);
%
%% TSPLOT2 - 3 subplots
subplot(3,1,1)
plot(year, y1, 'go-');
hold on
if lmin(1) > minY, % conditional added 1 Mar 15
   plot(xlimits, lmin, 'g--', 'LineWidth', 1); % minimum  - added 6 Oct 13
end
text(xmpos, ympos, '\fontname{times}\fontsize{10} z in log_{10}(y+z)', ...
    'Color', 'g');
title(['\fontname{times}\fontsize{14}' ddes ' \fontsize{10}from '...
        cd.df1n mess]);
ylabel(['\fontname{times}\fontsize{12}log10 of ' dsv1 ' (y1)']);
axis([xlimits minY maxY]);
grid on;
%
subplot(3,1,2)
plot(year, y2, 'ro-');
hold on
if lmin(1) > minY, % conditional added 1 Mar 15
   plot(xlimits, lmin, 'r--', 'LineWidth', 1); % minimum  - added 6 Oct 13
end
text(xmpos, ympos, '\fontname{times}\fontsize{10} z in log_{10}(y+z)', ...
    'Color', 'r');
title(['\fontname{times}\fontsize{10}plotted ' date ...
    ' by ' fname ' in ' prog_name]);
ylabel(['\fontname{times}\fontsize{12}log10 of ' dsv2 ' (y2)']);
axis([xlimits minY maxY]);
grid on;
%
subplot(3,1,3)
plot(year, ry3, 'bo-');
hold on
title('\fontname{times}\fontsize{12}ratio: y1/(y1+y2)');
ylabel('\fontname{times}\fontsize{12}ratio');
xlabel('\fontname{times}\fontsize{12}year (start)');
axis([xlimits [0 1]]);
grid on;

% output diagram using PIPrint
ori = 1; % selects for 'tall' orientation
ofn = strcat(uname, prog_name, '-ts', cd.df1n(1:4), num2str(begin_year));
PIPrint (cd.pt, ofn, 'time-series graph', ori);
%
    
% ==============================================================
function p = getnum(query, default)
% prompts user for a numeric value, with default
% input: query - a string; default - a numeric value
% output: p - a numeric value
p = input([query ' [' num2str(default) ']: ']);
if isempty(p), p = default; end