function [] = tsplot2b(data1, cd, data2)
% TSPLOT2B makes plots of timeseries data with ratio
%
% input
%   data1: 2D array of data in which
%       columns are: year.dec, y1, y2 [, more y]
%   cd : structure, control data
%   data2 : optional 2nd array of data
%           

% made by PT, 8 - 9 August 2008 as TSPLOT (called by PCI)
% PT, 6 Oct 2013 - plots nothing (rather than line) in years empty of data
% PT, 1 Mar 2015 - new version TSPLOT2, also plots ratio y1/(y1+y2)
% PT. 4 Sep 2015 - outputs using PIPRINT
% PT, 7 Sep 2015 - tidying up z1 and z2 values; only one input file
% PT, 30 Sep 2015 - allows for optional 2 data files
% PT, 12 Nov 2015 - lists data N in each year prior to year selection
% PT, 8 May 2016 - TSPLOT becomes TSPLOT2B; outputs more data statistics
% PT, 9 Aug 2016 - minor improvements
% =================================================================
%
global prog_name uname
fname = mfilename;
%% 1. START-UP
%
fprintf('%s\n', ['Graphing time-series of abundances with ' fname ':']);
fprintf('Y1 is %s and Y2 is %s\n', cd.dsv1, cd.dsv2);
data=data1; 
coldat = cd.c1dat; % column for date
colsv1 = cd.c1sv1; % columns for y variables
colsv2 = cd.c1sv2;
ddes = cd.d1des; % data source/description
colsvt1 = cd.c1svt1;  % numbers or biomass [only col 1 significant]
if colsvt1 == 1, % numbers
    z1 = cd.z1; % y value for zero
    z2 = cd.z2;
else
    z1 = cd.bz1;
    z2 = cd.bz2;
end
dsv1 = cd.dsv1; % names for variables and units
dsv2 = cd.dsv2;
if cd.ndf > 1.5, % there are two data-files, so check and update
  fprintf('%s\n', 'Two data files have been loaded:');  
  fprintf('%s\n', ['1. ' cd.df1n] );  
  fprintf('%s\n', ['2. ' cd.df2n] );
  wf = input('Which one do you want [1]:');
  if isempty(wf) || wf < 1.5, wf = 1; else wf = 2; end
  if wf > 1.5, 
    data=data2; 
    coldat = cd.c2dat; % column for date
    colsv1 = cd.c2sv1; % columns for y variables
    colsv2 = cd.c2sv2;
    ddes = cd.d2des; % data source/description
  end
end
%% 2. STATISTICS
%
% FOR THE Y VARIABLES - 8 MAY 2016
% assumes arithmetic variables
% 'floor' is used because CPR data are notionally integers, but can
% have a decimal added, e.g. .001, to indicate different count method
% summed over several taxa, this can add up to e.g. .007
% The flooring should be OK for microscope counts in cells/L
% *** NOT CLEAR WHAT IT WILL DO TO ZOOPLANKTON TOWNET DATA? 
fprintf('\n------- some statistics for the (floored) raw data:\n');
fprintf('Total number of rows: %8.0f \n', length(data(:,coldat))); 
y1vals = unique(floor(data(:,colsv1))); % vector of unique values of Y1
y2vals = unique(floor(data(:,colsv2))); % vector of unique values of Y2
% vectors are sorted in ascending order, so y1vals(1) is lowest
nuv = 5; % decide how many rows are needed at bottom end
mm = zeros(nuv+2,4); % nuv plus 2 rows of 4 columns
fprintf('Y1 value   number   Y2 value   number\n');
for uv = 1:nuv,
    if length(y1vals) >= uv,
        mm(uv,1) = y1vals(uv); 
        mm(uv,2) =  sum(ismember(floor(data(:,colsv1)),y1vals(uv)));
% tf = ismember(A, S) returns an array the same size as A, 
% containing logical 1 (true) where the elements of A are in the set S,
% and logical 0 (false) elsewhere.
    end
    if length(y2vals) >= uv,
        mm(uv,3)= y2vals(uv); 
        mm(uv,4) =  sum(ismember(floor(data(:,colsv2)),y2vals(uv)));
    end
    fprintf('%8.0f %8.0f %8.0f %8.0f \n', mm(uv,:));
end
y1max = max(y1vals); y1med = median(y1vals);
y2max = max(y2vals); y2med = median(y2vals);
uv=nuv+1;
mm(uv,1) = y1med; 
mm(uv,2) =  sum(ismember(floor(data(:,colsv1)),y1med));
mm(uv,3) = y2med; 
mm(uv,4) =  sum(ismember(floor(data(:,colsv2)),y2med));
uv=nuv+2;
mm(uv,1) = y1max; 
mm(uv,2) =  sum(ismember(floor(data(:,colsv1)),y1max));
mm(uv,3) = y2max; 
mm(uv,4) =  sum(ismember(floor(data(:,colsv2)),y2max));
fprintf('-- up to median, then maximum, of unique values \n');
fprintf('%8.0f %8.0f %8.0f %8.0f \n', mm(nuv+1,:));
fprintf('%8.0f %8.0f %8.0f %8.0f \n', mm(nuv+2,:));
fprintf('---------------------------------------\n');
%
% output state of averaging variable
fprintf('Control variable is set so that raw data are:\n');
if cd.mf > 1.5, 
    fprintf('-- averaged arithmetically within each month.\n');
else
    if cd.mf > 0.5, 
        fprintf('-- log-averaged within each month.\n');
    else
        if cd.mf >= 0, 
            fprintf('-- used as they are. \n');
        else
            fprintf('-- randomly subsampled with p = %4.2f \n', -cd.mf);
        end
    end
end
if cd.c1svt1 < 1.5, 
    fprintf('Variables (Y) are numbers, and\n');
fprintf('-- in log(Y + z), z1 = %5.0f and z2 = %5.0f \n', cd.z1, cd.z2);
else
     fprintf('Variables (Y) are biomass, and\n');
fprintf('-- in log(Y + z), z1 = %5.0f and z2 = %5.0f \n', cd.bz1, cd.bz2);
end
fprintf('---------------------------------------\n');
%
% FOR YEARS
% nupdated 9 August 2016 to count doubtle-zero rows
% ismember(floor(data(:,colsv1)), 0)  has 1 if zero in data
bothzero = ismember(floor(data(:,colsv1)), 0) ...
    & ismember(floor(data(:,colsv2)), 0);
years=unique(floor(data(:,coldat)));
fprintf('Current file is %s\n', cd.df1n); 
fprintf('%s\n', ...
'Available years of data (with N of data rows and N of both-zero) are:'); 
nr = zeros(1, length(years)); % number of rows per year
nrz = nr; % number of double-zero rows per year
for yr = 1:length(years),
    nr(yr) = sum(ismember(floor(data(:,coldat)),years(yr)));
    nrz(yr) = sum(ismember(floor(data(:,coldat)),years(yr)) & bothzero);
    fprintf('%8.0f (N =%5.0f, N0 =%5.0f ) ', years(yr), nr(yr), nrz(yr));
    if rem(yr, 3)==0, fprintf('\n'); end  % groups of three
end
fprintf('\n');
%
%% 3. DATA EXTRACTION
%
minyear=min(years); maxyear=max(years);
begin_year=floor(getnum(...
    '\n==Enter (integer) start year for plot :', minyear));
% add 0.999 to integer end_year include whole year
end_year=0.999 + floor(getnum(... 
    'Enter (integer) last full year for plot :', maxyear));
% 
% call extract2 with raw data; it returns transformed Y1 and Y2
% only uses one minimum, so
z = min([z1 z2]);
localdata = ...
     extract2(begin_year, end_year, z1, z2,...
        data, coldat, colsv1, colsv2, cd.mf);
    % deal with large gaps (> 1 yr) by inserting a row of NaN [6 Oct 13]
    % do this for any year between begin_year and end_year not in years 
    empty_years = setdiff(begin_year:end_year, years);
    ley = length(empty_years);
    lld = length(localdata(:,1));
    nogood = ones(ley,1)*NaN; % column vector of NaN
    localdata(lld+1:lld+ley,1) = empty_years';
    localdata(lld+1:lld+ley,2) = nogood;
    localdata(lld+1:lld+ley,3) = nogood;
    % now resort localdata (by rows) on column 1
    localdata = sortrows(localdata,1);
    % resume earlier commands
year = localdata(:,1);
y1 = localdata(:,2);
y2 = localdata(:,3);
% column 4, month, not used
% calculate ratio of Y1 to total
nly1 = 10.^y1 - z;% de-transform
nly2 = 10.^y2 - z;
ry3 = nly1./(nly1+nly2);
% %%%%%%%%

%% 4. MAKE THE PLOTS
%
clf;
% prepare scales [currently assuming that colsvt1 and colsvt2 the same]
%  - updated 6 Oct 2013
%     if cd.c1svt1 == 1, % using cell numbers as variable
%         minX=2.0;maxX=8.0;% default - changed from 6 to 8 on 16 Aug 2011
%     else % using biomass as the variable
%          minX=-5.0;maxX=2.0; % added 29 April 2013
%     end
%     % adjust maxima and minima if necessary
%      maxSV = max([max(y1) max(y2)] );
%      if maxSV>maxX, maxX=ceil(maxSV); end
%      maxY=maxX;
%      minSV = min([min(y1) min(y2) log10(z)]);
%      if minSV < minX, minX=floor(minSV); end
%     minY=minX;
% - revised 9 Oct 2015
if cd.c1svt1 == 1, % using cell numbers
    minX = cd.nmin; maxX = cd.nmax; % not used
    minY = cd.nmin; maxY = cd.nmax;
else
    minX = cd.bmin; maxX = cd.bmax; % not used
    minY = cd.bmin; maxY = cd.bmax;
end
%
if cd.mf > 0,
    mess = ' (monthly means)';
else
    if cd.mf < 0,
        mess = [' (subsampled 1 in ' num2str(-cd.mf) ')'];
    else
        mess = ' (all data used)';
    end
end
% make axis run to next whole year
xlimits = [begin_year ceil(end_year)]; 
lmin = [log10(z) log10(z)]; % for minimum
xmpos = xlimits(1) + 0.02*(xlimits(2)-xlimits(1));
ympos = lmin(1) - 0.05*(maxY - minY);
%
% 3 subplots ------------------------------------------------
%
subplot(3,1,1)
plot(year, y1, 'go-', 'LineWidth', 1);
hold on
if lmin(1) > minY, % conditional added 1 Mar 15
   plot(xlimits, lmin, 'g--', 'LineWidth', 1); % minimum  - added 6 Oct 13
end
text(xmpos, ympos, '\fontname{times}\fontsize{10} z in log_{10}(y+z)', ...
    'Color', 'g');
title(['\fontname{times}\fontsize{14}' ddes ' \fontsize{10}from '...
        cd.df1n mess]);
ylabel(['\fontname{times}\fontsize{12}log10 of ' dsv1 ' (y1)']);
axis([xlimits minY maxY]);
grid on;
%
subplot(3,1,2)
plot(year, y2, 'ro-', 'LineWidth', 1);
hold on
if lmin(1) > minY, % conditional added 1 Mar 15
   plot(xlimits, lmin, 'r--', 'LineWidth', 1); % minimum  - added 6 Oct 13
end
text(xmpos, ympos, '\fontname{times}\fontsize{10} z in log_{10}(y+z)', ...
    'Color', 'r');
title(['\fontname{times}\fontsize{10}plotted ' date ...
    ' by ' fname ' in ' prog_name]);
ylabel(['\fontname{times}\fontsize{12}log10 of ' dsv2 ' (y2)']);
axis([xlimits minY maxY]);
grid on;
%
subplot(3,1,3)
plot(year, ry3, 'bo-', 'LineWidth', 1);
hold on
title('\fontname{times}\fontsize{12}ratio: y1/(y1+y2)');
ylabel('\fontname{times}\fontsize{12}ratio');
xlabel('\fontname{times}\fontsize{12}year (start)');
axis([xlimits [0 1]]);
grid on;
%
% ------------------------------------------------------------
% output diagram using PIPrint
ori = 1; % selects for 'tall' orientation
ofn = strcat(uname, prog_name, '-ts', cd.df1n(1:4), num2str(begin_year));
PIPrint (cd.pt, ofn, 'time-series graph', ori);
%
    
%% ==============================================================
function p = getnum(query, default)
% prompts user for a numeric value, with default
% input: query - a string; default - a numeric value
% output: p - a numeric value
p = input([query ' [' num2str(default) ']: ']);
if isempty(p), p = default; end